@@ -1,6 +1,6 @@
 /* Key bindings and extended commands
    Copyright (c) 1997-2004 Sandro Sigala.
-   Copyright (c) 2003-2004 Reuben Thomas.
+   Copyright (c) 2003-2007 Reuben Thomas.
    All rights reserved.
 
    This file is part of Zile.
@@ -119,7 +119,8 @@ static void bind_key_vec(leafp tree, size_t *keys, size_t n, Function func)
 
 static void bind_key_string(char *key, Function func)
 {
-  size_t numkeys, *keys;
+  int numkeys;
+  size_t *keys;
 
   if ((numkeys = keystrtovec(key, &keys)) > 0) {
     bind_key_vec(leaf_tree, keys, numkeys, func);
@@ -170,7 +171,7 @@ static astr make_completion(size_t *keys, size_t numkeys)
   return astr_cat_char(as, '-');
 }
 
-static leafp completion_scan(size_t key, size_t **keys, size_t *numkeys)
+static leafp completion_scan(size_t key, size_t **keys, int *numkeys)
 {
   leafp p;
   vector *v = vec_new(sizeof(key));
@@ -192,35 +193,58 @@ static leafp completion_scan(size_t key, size_t **keys, size_t *numkeys)
   return p;
 }
 
+DEFUN("self-insert-command", self_insert_command)
+/*+
+Insert the character you type.
++*/
+{
+  int uni, ret = TRUE;
+
+  undo_save(UNDO_START_SEQUENCE, cur_bp->pt, 0, 0);
+  for (uni = 0; uni < uniarg; ++uni) {
+    /* Mask out ~KBD_CTRL to allow control sequences to be themselves. */
+    int key = lastkey() & ~KBD_CTRL;
+    deactivate_mark();
+    if (key <= 0xff) {
+      if (isspace(key) && cur_bp->flags & BFLAG_AUTOFILL &&
+          get_goalc() > (size_t)get_variable_number("fill-column"))
+        fill_break_line();
+      insert_char(key);
+    } else {
+      ding(); 
+      ret = FALSE;
+      break;
+    }
+  }
+  undo_save(UNDO_END_SEQUENCE, cur_bp->pt, 0, 0);
+
+  return ret;
+}
+END_DEFUN
+
 void process_key(size_t key)
 {
-  int uni;
-  size_t *keys = NULL, numkeys;
+  int numkeys;
+  size_t *keys = NULL;
   leafp p;
 
   if (key == KBD_NOKEY)
     return;
 
-  if (key & KBD_META && isdigit((int)(key & 255)))
+  if (key & KBD_META && isdigit((int)(key & 0xff)))
     /* Got an ESC x sequence where `x' is a digit. */
     universal_argument(KBD_META, (int)((key & 0xff) - '0'));
-  else {
-    if ((p = completion_scan(key, &keys, &numkeys)) == NULL) {
-      /* There are no bindings for the pressed key. */
-      undo_save(UNDO_START_SEQUENCE, cur_bp->pt, (size_t)0, (size_t)0);
-      for (uni = 0;
-           uni < last_uniarg && self_insert_command((ptrdiff_t)key);
-           ++uni);
-      undo_save(UNDO_END_SEQUENCE, cur_bp->pt, (size_t)0, (size_t)0);
-    } else {
-      p->func(last_uniarg, NULL);
-      _last_command = p->func;
-    }
-
-    free(keys);
+  else if ((p = completion_scan(key, &keys, &numkeys)) != NULL) {
+    p->func(last_uniarg, NULL);
+    _last_command = p->func;
+  } else {
+    astr as = keyvectostr(keys, numkeys);
+    minibuf_error("%s is undefined", astr_cstr(as));
+    astr_delete(as);
   }
+  free(keys);
 
-  /* Only add keystrokes if we're already in macro defining mode
+  /* Only add keystrokes if we were already in macro defining mode
      before the function call, to cope with start-kbd-macro. */
   if (lastflag & FLAG_DEFINING_MACRO && thisflag & FLAG_DEFINING_MACRO)
     add_cmd_to_macro();
@@ -273,10 +297,17 @@ static int bind_compar(const void *p1, const void *p2)
 
 void init_bindings(void)
 {
-  size_t i, j;
+  size_t i, j, *keys;
 
+  keys = zmalloc(sizeof(*keys));
   leaf_tree = leaf_new(10);
 
+  /* Bind all printing keys to self_insert_command */
+  for (i = 0; i <= 0xff; i++)
+    if (isprint(*keys = i))
+      bind_key_vec(leaf_tree, keys, 1, F_self_insert_command);
+  free(keys);
+  
   /* Bind all the default functions. */
   for (i = 0; i < fentry_table_size; i++)
     for (j = 0; j < 3; ++j)
@@ -332,23 +363,6 @@ char *get_function_name(Function p)
   return NULL;
 }
 
-static astr bindings_string(fentryp f)
-{
-  size_t i;
-  astr as = astr_new();
-
-  for (i = 0; i < 3; ++i) {
-    astr key = simplify_key(f->key[i]);
-    if (astr_len(key) > 0) {
-        astr_cat_cstr(as, (i == 0) ? "" : ", ");
-        astr_cat(as, key);
-    }
-    astr_delete(key);
-  }
-
-  return as;
-}
-
 /*
  * Read a function name from the minibuffer.
  * The returned buffer must be freed by the caller.
@@ -434,7 +448,7 @@ Read function name, then read its arguments and call it.
   char *name;
   astr msg = astr_new();
 
-  if (uniarg != 1)
+  if (lastflag & FLAG_SET_UNIARG)
     astr_afmt(msg, "%d M-x ", uniarg);
   else
     astr_cat_cstr(msg, "M-x ");
@@ -458,14 +472,14 @@ Read key sequence and function name, and bind the function to the key
 sequence.
 +*/
 {
-  int ok = FALSE;
-  size_t key, *keys = NULL, numkeys;
+  int ok = FALSE, numkeys;
+  size_t key, *keys = NULL;
   Function func;
   char *name;
 
-  if (list) {
-    numkeys = keystrtovec(list->list_next->data, &keys);
-    name = list->list_next->list_next->data;
+  if (arglist) {
+    numkeys = keystrtovec(arglist->list_next->data, &keys);
+    name = arglist->list_next->list_next->data;
   } else {
     astr as;
 
@@ -488,7 +502,7 @@ sequence.
   } else
     minibuf_error("No such function `%s'", name);
 
-  if (!list)
+  if (!arglist)
     free(name);
   free(keys);
 
@@ -496,61 +510,7 @@ sequence.
 }
 END_DEFUN
 
-DEFUN("where-is", where_is)
-/*+
-Print message listing key sequences that invoke the command DEFINITION.
-Argument is a command definition, usually a symbol with a function definition.
-If INSERT (the prefix arg) is non-nil, insert the message in the buffer.
-+*/
-{
-  char *name;
-  fentryp f;
-
-  name = minibuf_read_function_name("Where is command: ");
-
-  if (name == NULL || (f = get_fentry(name)) == NULL)
-    return FALSE;
-
-  if (f->key[0]) {
-    astr bindings = bindings_string(f);
-    astr as = astr_new();
-
-    astr_afmt(as, "%s is on %s", name, astr_cstr(bindings));
-    if (uniarg != 1)
-      bprintf("%s", astr_cstr(as));
-    else
-      minibuf_write("%s", astr_cstr(as));
-
-    astr_delete(as);
-    astr_delete(bindings);
-  } else
-    minibuf_write("%s is not on any key", name);
-
-  return TRUE;
-}
-END_DEFUN
-
-char *get_function_by_key_sequence(void)
-{
-  leafp p;
-  size_t c = getkey();
-  size_t *keys, numkeys;
-
-  if (c & KBD_META && isdigit((int)(c & 255)))
-    return "universal-argument";
-
-  p = completion_scan(c, &keys, &numkeys);
-  free(keys);
-  if (p == NULL) {
-    if (c == KBD_RET || c == KBD_TAB || c <= 255)
-      return "self-insert-command";
-    else
-      return NULL;
-  } else
-    return get_function_name(p->func);
-}
-
-static void write_bindings_tree(leafp tree, list keys)
+static void walk_bindings_tree(leafp tree, list keys, void (*process)(astr key, leafp p, void *st), void *st)
 {
   size_t i;
   list l;
@@ -569,36 +529,115 @@ static void write_bindings_tree(leafp tree, list keys)
         astr_cat(key, l->item);
         astr_cat_char(key, ' ');
       }
-      astr_cat(key, as);
-      astr_delete(as);
-      bprintf("%-15s %s\n", astr_cstr(key), get_function_name(p->func));
+      astr_cat_delete(key, as);
+      process(key, p, st);
       astr_delete(key);
     } else
-      write_bindings_tree(p, keys);
+      walk_bindings_tree(p, keys, process, st);
   }
 
   astr_delete(list_betail(keys));
 }
 
-static void write_bindings_list(va_list ap)
+static void walk_bindings(leafp tree, void (*process)(astr key, leafp p, void *st), void *st)
 {
   list l = list_new();
-
-  (void)ap;
-
-  bprintf("%-15s %s\n", "Binding", "Function");
-  bprintf("%-15s %s\n", "-------", "--------");
-
-  write_bindings_tree(leaf_tree, l);
+  walk_bindings_tree(tree, l, process, st);
   list_delete(l);
 }
 
-DEFUN("list-bindings", list_bindings)
+typedef struct {
+  Function f;
+  astr bindings;
+} gather_bindings_state;
+
+static void gather_bindings(astr key, leafp p, void *st)
+{
+  gather_bindings_state *g = (gather_bindings_state *)st;
+
+  if (p->func == g->f) {
+    if (astr_len(g->bindings) > 0)
+      astr_cat_cstr(g->bindings, ", ");
+    astr_cat(g->bindings, key);
+  }
+}
+
+DEFUN("where-is", where_is)
 /*+
-List defined bindings.
+Print message listing key sequences that invoke the command DEFINITION.
+Argument is a command name.  If the prefix arg is non-nil, insert the
+message in the buffer.
 +*/
 {
-  write_temp_buffer("*Bindings List*", write_bindings_list);
+  char *name = minibuf_read_function_name("Where is command: ");
+  int ret = FALSE;
+  gather_bindings_state g;
+
+  if (name && (g.f = get_function(name))) {
+    g.bindings = astr_new();
+    walk_bindings(leaf_tree, gather_bindings, &g);
+
+    if (astr_len(g.bindings) == 0)
+      minibuf_write("%s is not on any key", name);
+    else {
+      astr as = astr_new();
+      astr_afmt(as, "%s is on %s", name, astr_cstr(g.bindings));
+      if (lastflag & FLAG_SET_UNIARG)
+        bprintf("%s", astr_cstr(as));
+      else
+        minibuf_write("%s", astr_cstr(as));
+      astr_delete(as);
+    }
+    astr_delete(g.bindings);
+    ret = TRUE;
+  }
+
+  free(name);
+  return ret;
+}
+END_DEFUN
+
+char *get_function_by_key_sequence(size_t **keys, int *numkeys)
+{
+  leafp p;
+  size_t c = getkey();
+
+  if (c & KBD_META && isdigit((int)(c & 0xff))) {
+    *numkeys = 1;
+    *keys = malloc(sizeof(**keys));
+    *keys[0] = c;
+    return "universal-argument";
+  }
+
+  p = completion_scan(c, keys, numkeys);
+  if (p == NULL)
+    return NULL;
+  else
+    return get_function_name(p->func);
+}
+
+static void print_binding(astr key, leafp p, void *st GCC_UNUSED)
+{
+  bprintf("%-15s %s\n", astr_cstr(key), get_function_name(p->func));
+}
+
+static void write_bindings_list(va_list ap)
+{
+  (void)ap;
+
+  bprintf("Global Bindings:");
+  bprintf("%-15s %s\n", "key", "binding");
+  bprintf("%-15s %s\n", "---", "-------");
+
+  walk_bindings(leaf_tree, print_binding, NULL);
+}
+
+DEFUN("describe-bindings", describe_bindings)
+/*+
+Show a list of all defined keys, and their definitions.
++*/
+{
+  write_temp_buffer("*Help*", write_bindings_list);
   return TRUE;
 }
 END_DEFUN
