@@ -20,7 +20,7 @@ int scroll_up(void);
 size_t do_completion(astr as);
 char *minibuf_read_function_name(const char *fmt, ...);
 int execute_function(char *name, int uniarg);
-char *get_function_by_key_sequence(void);
+char *get_function_by_key_sequence(size_t **keys, int *numkeys);
 void process_key(size_t key);
 void init_bindings(void);
 Function last_command(void);
@@ -99,6 +99,7 @@ int backward_sexp(void);
 /* glue.c ----------------------------------------------------------------- */
 void ding(void);
 void ungetkey(size_t key);
+size_t lastkey(void);
 size_t xgetkey(int mode, size_t timeout);
 size_t getkey(void);
 void waitkey(size_t delay);
@@ -135,7 +136,6 @@ int insert_newline(void);
 int intercalate_newline(void);
 void insert_string(const char *s);
 void insert_nstring(const char *s, size_t size);
-int self_insert_command(int c);
 void bprintf(const char *fmt, ...);
 int delete_char(void);
 int backward_delete_char(void);
@@ -179,7 +179,6 @@ void minibuf_error(const char *fmt, ...);
 void minibuf_write(const char *fmt, ...);
 char *minibuf_read(const char *fmt, const char *value, ...);
 int minibuf_read_yesno(const char *fmt, ...);
-int minibuf_read_boolean(const char *fmt, ...);
 char *minibuf_read_dir(const char *fmt, const char *value, ...);
 char *minibuf_read_completion(const char *fmt, char *value, Completion *cp, History *hp, ...);
 void minibuf_clear(void);
@@ -219,7 +218,6 @@ void term_full_redisplay(void);
 void show_splash_screen(const char *splash);
 void term_tidy(void);
 void term_addnstr(const char *s, size_t len);
-int term_printw(const char *fmt, ...);
 
 /* term_termcap.c --------------------------------------------------------- */
 void term_init(void);
