@@ -401,43 +401,6 @@ void insert_nstring(const char *s, size_t size)
   undo_nosave = FALSE;
 }
 
-int self_insert_command(int c)
-{
-  deactivate_mark();
-
-  if (c <= 255) {
-    if (isspace(c) && cur_bp->flags & BFLAG_AUTOFILL &&
-        get_goalc() > (size_t)get_variable_number("fill-column"))
-      fill_break_line();
-    insert_char(c);
-    return TRUE;
-  } else {
-    ding();
-    return FALSE;
-  }
-}
-
-DEFUN("self-insert-command", self_insert_command)
-/*+
-Insert the character you type.
-+*/
-{
-  int uni, c, ret = TRUE;
-
-  c = getkey();
-
-  undo_save(UNDO_START_SEQUENCE, cur_bp->pt, 0, 0);
-  for (uni = 0; uni < uniarg; ++uni)
-    if (!self_insert_command(c)) {
-      ret = FALSE;
-      break;
-    }
-  undo_save(UNDO_END_SEQUENCE, cur_bp->pt, 0, 0);
-
-  return ret;
-}
-END_DEFUN
-
 void bprintf(const char *fmt, ...)
 {
   va_list ap;
@@ -460,16 +423,8 @@ int delete_char(void)
     undo_save(UNDO_INTERCALATE_CHAR, cur_bp->pt,
               (size_t)(*astr_char(cur_bp->pt.p->item,
                                     (ptrdiff_t)cur_bp->pt.o)), 0);
-
-    /*
-     * Move the text one position backward after the point,
-     * if required.
-     * This code assumes that memmove(d, s, 0) does nothing.
-     */
     astr_remove(cur_bp->pt.p->item, (ptrdiff_t)cur_bp->pt.o, 1);
-
     adjust_markers(cur_bp->pt.p, cur_bp->pt.p, cur_bp->pt.o, 0, -1);
-
     cur_bp->flags |= BFLAG_MODIFIED;
 
     return TRUE;
@@ -574,9 +529,7 @@ Delete the previous character.
 Join lines if the character is a newline.
 +*/
 {
-  /* In overwrite-mode and isn't called by delete_char().  */
-  int (*f)(void) = ((cur_bp->flags & BFLAG_OVERWRITE) &&
-                    (last_uniarg > 0)) ?
+  int (*f)(void) = cur_bp->flags & BFLAG_OVERWRITE ?
     backward_delete_char_overwrite : backward_delete_char;
   int uni, ret = TRUE;
 
